==> cost-interface-0.3.41-sources.jar: com/chinayanghe/tpm/cost/vo/in/SaleLimitDetailVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;
import java.util.Date;

/**
 * 销量明细(登记)
 * SaleLimitDetailDto
 * 数据库表：sale_limit_detail
 */
public class SaleLimitDetailVo implements Serializable {

    /**
     * 
     * 表字段 : sale_limit_detail.id
     */
    private Integer id;

    /**
     * 发票凭证号
     * 表字段 : sale_limit_detail.invoice_no
     */
    private String invoiceNo;

    /**
     * 流水单据号
     * 表字段 : sale_limit_detail.serial_no
     */
    private String serialNo;

    /**
     * 登记单号
     * 表字段 : sale_limit_detail.regist_no
     */
    private String registNo;

    /**
     * 销量登记行号
     * 表字段 : sale_limit_detail.sale_limit_item_no
     */
    private Integer saleLimitItemNo;

    /**
     * 开票标示编码
     * 表字段 : sale_limit_detail.ticket_mark_id
     */
    private String ticketMarkId;

    /**
     * 开票标示
     * 表字段 : sale_limit_detail.ticket_mark
     */
    private String ticketMark;

    /**
     * 发票行项目号
     * 表字段 : sale_limit_detail.ticket_item_no
     */
    private String ticketItemNo;

    /**
     * 公司编码
     * 表字段 : sale_limit_detail.company_id
     */
    private String companyId;
    
    /**
     * 分公司编码
     * 表字段 : sale_limit_detail.company_id
     */
    private String companySubId;

    /**
     * 经销商编码
     * 表字段 : sale_limit_detail.dealer_id
     */
    private String dealerId;

    /**
     * 经销商名称
     * 表字段 : sale_limit_detail.dealer_name
     */
    private String dealerName;

    /**
     * 产品编码
     * 表字段 : sale_limit_detail.product_id
     */
    private String productId;

    /**
     * 产品名称
     * 表字段 : sale_limit_detail.product_name
     */
    private String productName;

    /**
     * 产品数量
     * 表字段 : sale_limit_detail.product_num
     */
    private Integer productNum;

    /**
     * 期间控制消耗量
     * 表字段 : sale_limit_detail.current_procut_num
     */
    private Integer currentProcutNum;

    /**
     * 开票日期
     * 表字段 : sale_limit_detail.ticket_date
     */
    private Date ticketDate;
    
    private Integer amount;//金额

    /**
     * 状态编号
     * 表字段 : sale_limit_detail.ticket_status
     */
    private Integer ticketStatus;

    /**
     * 状态描述
     * 表字段 : sale_limit_detail.ticket_status_name
     */
    private String ticketStatusName;

    /**
     * 核报单号
     * 表字段 : sale_limit_detail.pay_no
     */
    private String payNo;

    /**
     * 行号
     * 表字段 : sale_limit_detail.item_no
     */
    private Integer itemNo;

    /**
     * 
     * 表字段 : sale_limit_detail.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : sale_limit_detail.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : sale_limit_detail.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : sale_limit_detail.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : sale_limit_detail.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : sale_limit_detail.modify_date
     */
    private Date modifyDate;

    /**
     * This field was generated by MyBatis Generator.
     * This field corresponds to the database table sale_limit_detail
     *
     * @mbggenerated Sat Jun 03 17:03:16 CST 2017
     */
    private static final long serialVersionUID = 1L;

    /**
     * 获取  字段:sale_limit_detail.id
     *
     * @return sale_limit_detail.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:sale_limit_detail.id
     *
     * @param id the value for sale_limit_detail.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 发票凭证号 字段:sale_limit_detail.invoice_no
     *
     * @return sale_limit_detail.invoice_no, 发票凭证号
     */
    public String getInvoiceNo() {
        return invoiceNo;
    }

    /**
     * 设置 发票凭证号 字段:sale_limit_detail.invoice_no
     *
     * @param invoiceNo the value for sale_limit_detail.invoice_no, 发票凭证号
     */
    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    /**
     * 获取 流水单据号 字段:sale_limit_detail.serial_no
     *
     * @return sale_limit_detail.serial_no, 流水单据号
     */
    public String getSerialNo() {
        return serialNo;
    }

    /**
     * 设置 流水单据号 字段:sale_limit_detail.serial_no
     *
     * @param serialNo the value for sale_limit_detail.serial_no, 流水单据号
     */
    public void setSerialNo(String serialNo) {
        this.serialNo = serialNo;
    }

    /**
     * 获取 登记单号 字段:sale_limit_detail.regist_no
     *
     * @return sale_limit_detail.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:sale_limit_detail.regist_no
     *
     * @param registNo the value for sale_limit_detail.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 销量登记行号 字段:sale_limit_detail.sale_limit_item_no
     *
     * @return sale_limit_detail.sale_limit_item_no, 销量登记行号
     */
    public Integer getSaleLimitItemNo() {
        return saleLimitItemNo;
    }

    /**
     * 设置 销量登记行号 字段:sale_limit_detail.sale_limit_item_no
     *
     * @param saleLimitItemNo the value for sale_limit_detail.sale_limit_item_no, 销量登记行号
     */
    public void setSaleLimitItemNo(Integer saleLimitItemNo) {
        this.saleLimitItemNo = saleLimitItemNo;
    }

    /**
     * 获取 开票标示编码 字段:sale_limit_detail.ticket_mark_id
     *
     * @return sale_limit_detail.ticket_mark_id, 开票标示编码
     */
    public String getTicketMarkId() {
        return ticketMarkId;
    }

    /**
     * 设置 开票标示编码 字段:sale_limit_detail.ticket_mark_id
     *
     * @param ticketMarkId the value for sale_limit_detail.ticket_mark_id, 开票标示编码
     */
    public void setTicketMarkId(String ticketMarkId) {
        this.ticketMarkId = ticketMarkId;
    }

    /**
     * 获取 开票标示 字段:sale_limit_detail.ticket_mark
     *
     * @return sale_limit_detail.ticket_mark, 开票标示
     */
    public String getTicketMark() {
        return ticketMark;
    }

    /**
     * 设置 开票标示 字段:sale_limit_detail.ticket_mark
     *
     * @param ticketMark the value for sale_limit_detail.ticket_mark, 开票标示
     */
    public void setTicketMark(String ticketMark) {
        this.ticketMark = ticketMark;
    }

    /**
     * 获取 发票行项目号 字段:sale_limit_detail.ticket_item_no
     *
     * @return sale_limit_detail.ticket_item_no, 发票行项目号
     */
    public String getTicketItemNo() {
        return ticketItemNo;
    }

    /**
     * 设置 发票行项目号 字段:sale_limit_detail.ticket_item_no
     *
     * @param ticketItemNo the value for sale_limit_detail.ticket_item_no, 发票行项目号
     */
    public void setTicketItemNo(String ticketItemNo) {
        this.ticketItemNo = ticketItemNo;
    }

    /**
     * 获取 公司编码 字段:sale_limit_detail.company_id
     *
     * @return sale_limit_detail.company_id, 公司编码
     */
    public String getCompanyId() {
        return companyId;
    }

    /**
     * 设置 公司编码 字段:sale_limit_detail.company_id
     *
     * @param companyId the value for sale_limit_detail.company_id, 公司编码
     */
    public void setCompanyId(String companyId) {
        this.companyId = companyId;
    }

    /**
     * 获取 经销商编码 字段:sale_limit_detail.dealer_id
     *
     * @return sale_limit_detail.dealer_id, 经销商编码
     */
    public String getDealerId() {
        return dealerId;
    }

    /**
     * 设置 经销商编码 字段:sale_limit_detail.dealer_id
     *
     * @param dealerId the value for sale_limit_detail.dealer_id, 经销商编码
     */
    public void setDealerId(String dealerId) {
        this.dealerId = dealerId;
    }

    /**
     * 获取 经销商名称 字段:sale_limit_detail.dealer_name
     *
     * @return sale_limit_detail.dealer_name, 经销商名称
     */
    public String getDealerName() {
        return dealerName;
    }

    /**
     * 设置 经销商名称 字段:sale_limit_detail.dealer_name
     *
     * @param dealerName the value for sale_limit_detail.dealer_name, 经销商名称
     */
    public void setDealerName(String dealerName) {
        this.dealerName = dealerName;
    }

    /**
     * 获取 产品编码 字段:sale_limit_detail.product_id
     *
     * @return sale_limit_detail.product_id, 产品编码
     */
    public String getProductId() {
        return productId;
    }

    /**
     * 设置 产品编码 字段:sale_limit_detail.product_id
     *
     * @param productId the value for sale_limit_detail.product_id, 产品编码
     */
    public void setProductId(String productId) {
        this.productId = productId;
    }

    /**
     * 获取 产品名称 字段:sale_limit_detail.product_name
     *
     * @return sale_limit_detail.product_name, 产品名称
     */
    public String getProductName() {
        return productName;
    }

    /**
     * 设置 产品名称 字段:sale_limit_detail.product_name
     *
     * @param productName the value for sale_limit_detail.product_name, 产品名称
     */
    public void setProductName(String productName) {
        this.productName = productName;
    }

    /**
     * 获取 产品数量 字段:sale_limit_detail.product_num
     *
     * @return sale_limit_detail.product_num, 产品数量
     */
    public Integer getProductNum() {
        return productNum;
    }

    /**
     * 设置 产品数量 字段:sale_limit_detail.product_num
     *
     * @param productNum the value for sale_limit_detail.product_num, 产品数量
     */
    public void setProductNum(Integer productNum) {
        this.productNum = productNum;
    }

    /**
     * 获取 当前量 字段:sale_limit_detail.current_procut_num
     *
     * @return sale_limit_detail.current_procut_num, 期间控制消耗量
     */
    public Integer getCurrentProcutNum() {
        return currentProcutNum;
    }

    /**
     * 设置 当前量 字段:sale_limit_detail.current_procut_num
     *
     * @param currentProcutNum the value for sale_limit_detail.current_procut_num, 期间控制消耗量
     */
    public void setCurrentProcutNum(Integer currentProcutNum) {
        this.currentProcutNum = currentProcutNum;
    }

    /**
     * 获取 开票日期 字段:sale_limit_detail.ticket_date
     *
     * @return sale_limit_detail.ticket_date, 开票日期
     */
    public Date getTicketDate() {
        return ticketDate;
    }

    /**
     * 设置 开票日期 字段:sale_limit_detail.ticket_date
     *
     * @param ticketDate the value for sale_limit_detail.ticket_date, 开票日期
     */
    public void setTicketDate(Date ticketDate) {
        this.ticketDate = ticketDate;
    }

   

	public Integer getAmount() {
		return amount;
	}

	public void setAmount(Integer amount) {
		this.amount = amount;
	}

	/**
     * 获取 状态编号 字段:sale_limit_detail.ticket_status
     *
     * @return sale_limit_detail.ticket_status, 状态编号
     */
    public Integer getTicketStatus() {
        return ticketStatus;
    }

    /**
     * 设置 状态编号 字段:sale_limit_detail.ticket_status
     *
     * @param ticketStatus the value for sale_limit_detail.ticket_status, 状态编号
     */
    public void setTicketStatus(Integer ticketStatus) {
        this.ticketStatus = ticketStatus;
    }

    /**
     * 获取 状态描述 字段:sale_limit_detail.ticket_status_name
     *
     * @return sale_limit_detail.ticket_status_name, 状态描述
     */
    public String getTicketStatusName() {
        return ticketStatusName;
    }

    /**
     * 设置 状态描述 字段:sale_limit_detail.ticket_status_name
     *
     * @param ticketStatusName the value for sale_limit_detail.ticket_status_name, 状态描述
     */
    public void setTicketStatusName(String ticketStatusName) {
        this.ticketStatusName = ticketStatusName;
    }

    /**
     * 获取 核报单号 字段:sale_limit_detail.pay_no
     *
     * @return sale_limit_detail.pay_no, 核报单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 核报单号 字段:sale_limit_detail.pay_no
     *
     * @param payNo the value for sale_limit_detail.pay_no, 核报单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 行号 字段:sale_limit_detail.item_no
     *
     * @return sale_limit_detail.item_no, 行号
     */
    public Integer getItemNo() {
        return itemNo;
    }

    /**
     * 设置 行号 字段:sale_limit_detail.item_no
     *
     * @param itemNo the value for sale_limit_detail.item_no, 行号
     */
    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取  字段:sale_limit_detail.create_id
     *
     * @return sale_limit_detail.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:sale_limit_detail.create_id
     *
     * @param createId the value for sale_limit_detail.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:sale_limit_detail.create_name
     *
     * @return sale_limit_detail.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:sale_limit_detail.create_name
     *
     * @param createName the value for sale_limit_detail.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:sale_limit_detail.create_date
     *
     * @return sale_limit_detail.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:sale_limit_detail.create_date
     *
     * @param createDate the value for sale_limit_detail.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:sale_limit_detail.modify_id
     *
     * @return sale_limit_detail.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:sale_limit_detail.modify_id
     *
     * @param modifyId the value for sale_limit_detail.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:sale_limit_detail.modify_name
     *
     * @return sale_limit_detail.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:sale_limit_detail.modify_name
     *
     * @param modifyName the value for sale_limit_detail.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:sale_limit_detail.modify_date
     *
     * @return sale_limit_detail.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }
    
    

    public String getCompanySubId() {
		return companySubId;
	}

	public void setCompanySubId(String companySubId) {
		this.companySubId = companySubId;
	}

	/**
     * 设置  字段:sale_limit_detail.modify_date
     *
     * @param modifyDate the value for sale_limit_detail.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}

==> cost-interface-0.3.46-sources.jar: com/chinayanghe/tpm/cost/vo/in/SaleLimitDetailVo.java <==
package com.chinayanghe.tpm.cost.vo.in;

import java.io.Serializable;
import java.util.Date;

/**
 * 销量明细(登记)
 * SaleLimitDetailDto
 * 数据库表：sale_limit_detail
 */
public class SaleLimitDetailVo implements Serializable {

    /**
     * 
     * 表字段 : sale_limit_detail.id
     */
    private Integer id;
    
    private Integer isOldWine=0;//是否老名酒

    /**
     * 发票凭证号
     * 表字段 : sale_limit_detail.invoice_no
     */
    private String invoiceNo;

    /**
     * 流水单据号
     * 表字段 : sale_limit_detail.serial_no
     */
    private String serialNo;

    /**
     * 登记单号
     * 表字段 : sale_limit_detail.regist_no
     */
    private String registNo;

    /**
     * 销量登记行号
     * 表字段 : sale_limit_detail.sale_limit_item_no
     */
    private Integer saleLimitItemNo;

    /**
     * 开票标示编码
     * 表字段 : sale_limit_detail.ticket_mark_id
     */
    private String ticketMarkId;

    /**
     * 开票标示
     * 表字段 : sale_limit_detail.ticket_mark
     */
    private String ticketMark;

    /**
     * 发票行项目号
     * 表字段 : sale_limit_detail.ticket_item_no
     */
    private String ticketItemNo;

    /**
     * 公司编码
     * 表字段 : sale_limit_detail.company_id
     */
    private String companyId;
    
    /**
     * 分公司编码
     * 表字段 : sale_limit_detail.company_id
     */
    private String companySubId;

    /**
     * 经销商编码
     * 表字段 : sale_limit_detail.dealer_id
     */
    private String dealerId;

    /**
     * 经销商名称
     * 表字段 : sale_limit_detail.dealer_name
     */
    private String dealerName;

    /**
     * 产品编码
     * 表字段 : sale_limit_detail.product_id
     */
    private String productId;

    /**
     * 产品名称
     * 表字段 : sale_limit_detail.product_name
     */
    private String productName;

    /**
     * 产品数量
     * 表字段 : sale_limit_detail.product_num
     */
    private Integer productNum;

    /**
     * 期间控制消耗量
     * 表字段 : sale_limit_detail.current_procut_num
     */
    private Integer currentProcutNum;

    /**
     * 开票日期
     * 表字段 : sale_limit_detail.ticket_date
     */
    private Date ticketDate;
    
    private Integer amount;//金额

    /**
     * 状态编号
     * 表字段 : sale_limit_detail.ticket_status
     */
    private Integer ticketStatus;

    /**
     * 状态描述
     * 表字段 : sale_limit_detail.ticket_status_name
     */
    private String ticketStatusName;

    /**
     * 核报单号
     * 表字段 : sale_limit_detail.pay_no
     */
    private String payNo;

    /**
     * 行号
     * 表字段 : sale_limit_detail.item_no
     */
    private Integer itemNo;

    /**
     * 
     * 表字段 : sale_limit_detail.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : sale_limit_detail.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : sale_limit_detail.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : sale_limit_detail.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : sale_limit_detail.modify_name
     */
    private String modifyName;
    
    

    /**
     * 
     * 表字段 : sale_limit_detail.modify_date
     */
    private Date modifyDate;

    /**
     * This field was generated by MyBatis Generator.
     * This field corresponds to the database table sale_limit_detail
     *
     * @mbggenerated Sat Jun 03 17:03:16 CST 2017
     */
    private static final long serialVersionUID = 1L;

    /**
     * 获取  字段:sale_limit_detail.id
     *
     * @return sale_limit_detail.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:sale_limit_detail.id
     *
     * @param id the value for sale_limit_detail.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 发票凭证号 字段:sale_limit_detail.invoice_no
     *
     * @return sale_limit_detail.invoice_no, 发票凭证号
     */
    public String getInvoiceNo() {
        return invoiceNo;
    }

    /**
     * 设置 发票凭证号 字段:sale_limit_detail.invoice_no
     *
     * @param invoiceNo the value for sale_limit_detail.invoice_no, 发票凭证号
     */
    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    /**
     * 获取 流水单据号 字段:sale_limit_detail.serial_no
     *
     * @return sale_limit_detail.serial_no, 流水单据号
     */
    public String getSerialNo() {
        return serialNo;
    }

    /**
     * 设置 流水单据号 字段:sale_limit_detail.serial_no
     *
     * @param serialNo the value for sale_limit_detail.serial_no, 流水单据号
     */
    public void setSerialNo(String serialNo) {
        this.serialNo = serialNo;
    }

    /**
     * 获取 登记单号 字段:sale_limit_detail.regist_no
     *
     * @return sale_limit_detail.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:sale_limit_detail.regist_no
     *
     * @param registNo the value for sale_limit_detail.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    /**
     * 获取 销量登记行号 字段:sale_limit_detail.sale_limit_item_no
     *
     * @return sale_limit_detail.sale_limit_item_no, 销量登记行号
     */
    public Integer getSaleLimitItemNo() {
        return saleLimitItemNo;
    }

    /**
     * 设置 销量登记行号 字段:sale_limit_detail.sale_limit_item_no
     *
     * @param saleLimitItemNo the value for sale_limit_detail.sale_limit_item_no, 销量登记行号
     */
    public void setSaleLimitItemNo(Integer saleLimitItemNo) {
        this.saleLimitItemNo = saleLimitItemNo;
    }

    /**
     * 获取 开票标示编码 字段:sale_limit_detail.ticket_mark_id
     *
     * @return sale_limit_detail.ticket_mark_id, 开票标示编码
     */
    public String getTicketMarkId() {
        return ticketMarkId;
    }

    /**
     * 设置 开票标示编码 字段:sale_limit_detail.ticket_mark_id
     *
     * @param ticketMarkId the value for sale_limit_detail.ticket_mark_id, 开票标示编码
     */
    public void setTicketMarkId(String ticketMarkId) {
        this.ticketMarkId = ticketMarkId;
    }

    /**
     * 获取 开票标示 字段:sale_limit_detail.ticket_mark
     *
     * @return sale_limit_detail.ticket_mark, 开票标示
     */
    public String getTicketMark() {
        return ticketMark;
    }

    /**
     * 设置 开票标示 字段:sale_limit_detail.ticket_mark
     *
     * @param ticketMark the value for sale_limit_detail.ticket_mark, 开票标示
     */
    public void setTicketMark(String ticketMark) {
        this.ticketMark = ticketMark;
    }

    /**
     * 获取 发票行项目号 字段:sale_limit_detail.ticket_item_no
     *
     * @return sale_limit_detail.ticket_item_no, 发票行项目号
     */
    public String getTicketItemNo() {
        return ticketItemNo;
    }

    /**
     * 设置 发票行项目号 字段:sale_limit_detail.ticket_item_no
     *
     * @param ticketItemNo the value for sale_limit_detail.ticket_item_no, 发票行项目号
     */
    public void setTicketItemNo(String ticketItemNo) {
        this.ticketItemNo = ticketItemNo;
    }

    /**
     * 获取 公司编码 字段:sale_limit_detail.company_id
     *
     * @return sale_limit_detail.company_id, 公司编码
     */
    public String getCompanyId() {
        return companyId;
    }

    /**
     * 设置 公司编码 字段:sale_limit_detail.company_id
     *
     * @param companyId the value for sale_limit_detail.company_id, 公司编码
     */
    public void setCompanyId(String companyId) {
        this.companyId = companyId;
    }

    /**
     * 获取 经销商编码 字段:sale_limit_detail.dealer_id
     *
     * @return sale_limit_detail.dealer_id, 经销商编码
     */
    public String getDealerId() {
        return dealerId;
    }

    /**
     * 设置 经销商编码 字段:sale_limit_detail.dealer_id
     *
     * @param dealerId the value for sale_limit_detail.dealer_id, 经销商编码
     */
    public void setDealerId(String dealerId) {
        this.dealerId = dealerId;
    }

    /**
     * 获取 经销商名称 字段:sale_limit_detail.dealer_name
     *
     * @return sale_limit_detail.dealer_name, 经销商名称
     */
    public String getDealerName() {
        return dealerName;
    }

    /**
     * 设置 经销商名称 字段:sale_limit_detail.dealer_name
     *
     * @param dealerName the value for sale_limit_detail.dealer_name, 经销商名称
     */
    public void setDealerName(String dealerName) {
        this.dealerName = dealerName;
    }

    /**
     * 获取 产品编码 字段:sale_limit_detail.product_id
     *
     * @return sale_limit_detail.product_id, 产品编码
     */
    public String getProductId() {
        return productId;
    }

    /**
     * 设置 产品编码 字段:sale_limit_detail.product_id
     *
     * @param productId the value for sale_limit_detail.product_id, 产品编码
     */
    public void setProductId(String productId) {
        this.productId = productId;
    }

    /**
     * 获取 产品名称 字段:sale_limit_detail.product_name
     *
     * @return sale_limit_detail.product_name, 产品名称
     */
    public String getProductName() {
        return productName;
    }

    /**
     * 设置 产品名称 字段:sale_limit_detail.product_name
     *
     * @param productName the value for sale_limit_detail.product_name, 产品名称
     */
    public void setProductName(String productName) {
        this.productName = productName;
    }

    /**
     * 获取 产品数量 字段:sale_limit_detail.product_num
     *
     * @return sale_limit_detail.product_num, 产品数量
     */
    public Integer getProductNum() {
        return productNum;
    }

    /**
     * 设置 产品数量 字段:sale_limit_detail.product_num
     *
     * @param productNum the value for sale_limit_detail.product_num, 产品数量
     */
    public void setProductNum(Integer productNum) {
        this.productNum = productNum;
    }

    /**
     * 获取 当前量 字段:sale_limit_detail.current_procut_num
     *
     * @return sale_limit_detail.current_procut_num, 期间控制消耗量
     */
    public Integer getCurrentProcutNum() {
        return currentProcutNum;
    }

    /**
     * 设置 当前量 字段:sale_limit_detail.current_procut_num
     *
     * @param currentProcutNum the value for sale_limit_detail.current_procut_num, 期间控制消耗量
     */
    public void setCurrentProcutNum(Integer currentProcutNum) {
        this.currentProcutNum = currentProcutNum;
    }

    /**
     * 获取 开票日期 字段:sale_limit_detail.ticket_date
     *
     * @return sale_limit_detail.ticket_date, 开票日期
     */
    public Date getTicketDate() {
        return ticketDate;
    }

    /**
     * 设置 开票日期 字段:sale_limit_detail.ticket_date
     *
     * @param ticketDate the value for sale_limit_detail.ticket_date, 开票日期
     */
    public void setTicketDate(Date ticketDate) {
        this.ticketDate = ticketDate;
    }

   

	public Integer getAmount() {
		return amount;
	}

	public void setAmount(Integer amount) {
		this.amount = amount;
	}

	/**
     * 获取 状态编号 字段:sale_limit_detail.ticket_status
     *
     * @return sale_limit_detail.ticket_status, 状态编号
     */
    public Integer getTicketStatus() {
        return ticketStatus;
    }

    /**
     * 设置 状态编号 字段:sale_limit_detail.ticket_status
     *
     * @param ticketStatus the value for sale_limit_detail.ticket_status, 状态编号
     */
    public void setTicketStatus(Integer ticketStatus) {
        this.ticketStatus = ticketStatus;
    }

    /**
     * 获取 状态描述 字段:sale_limit_detail.ticket_status_name
     *
     * @return sale_limit_detail.ticket_status_name, 状态描述
     */
    public String getTicketStatusName() {
        return ticketStatusName;
    }

    /**
     * 设置 状态描述 字段:sale_limit_detail.ticket_status_name
     *
     * @param ticketStatusName the value for sale_limit_detail.ticket_status_name, 状态描述
     */
    public void setTicketStatusName(String ticketStatusName) {
        this.ticketStatusName = ticketStatusName;
    }

    public Integer getIsOldWine() {
		return isOldWine;
	}

	public void setIsOldWine(Integer isOldWine) {
		this.isOldWine = isOldWine;
	}

	/**
     * 获取 核报单号 字段:sale_limit_detail.pay_no
     *
     * @return sale_limit_detail.pay_no, 核报单号
     */
    public String getPayNo() {
        return payNo;
    }

    /**
     * 设置 核报单号 字段:sale_limit_detail.pay_no
     *
     * @param payNo the value for sale_limit_detail.pay_no, 核报单号
     */
    public void setPayNo(String payNo) {
        this.payNo = payNo;
    }

    /**
     * 获取 行号 字段:sale_limit_detail.item_no
     *
     * @return sale_limit_detail.item_no, 行号
     */
    public Integer getItemNo() {
        return itemNo;
    }

    /**
     * 设置 行号 字段:sale_limit_detail.item_no
     *
     * @param itemNo the value for sale_limit_detail.item_no, 行号
     */
    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取  字段:sale_limit_detail.create_id
     *
     * @return sale_limit_detail.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:sale_limit_detail.create_id
     *
     * @param createId the value for sale_limit_detail.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:sale_limit_detail.create_name
     *
     * @return sale_limit_detail.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:sale_limit_detail.create_name
     *
     * @param createName the value for sale_limit_detail.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:sale_limit_detail.create_date
     *
     * @return sale_limit_detail.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:sale_limit_detail.create_date
     *
     * @param createDate the value for sale_limit_detail.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:sale_limit_detail.modify_id
     *
     * @return sale_limit_detail.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:sale_limit_detail.modify_id
     *
     * @param modifyId the value for sale_limit_detail.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:sale_limit_detail.modify_name
     *
     * @return sale_limit_detail.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:sale_limit_detail.modify_name
     *
     * @param modifyName the value for sale_limit_detail.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:sale_limit_detail.modify_date
     *
     * @return sale_limit_detail.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }
    
    

    public String getCompanySubId() {
		return companySubId;
	}

	public void setCompanySubId(String companySubId) {
		this.companySubId = companySubId;
	}

	/**
     * 设置  字段:sale_limit_detail.modify_date
     *
     * @param modifyDate the value for sale_limit_detail.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}
